# PyRAMS 
## Useful tools for working with RAMS data

[![Documentation Status](https://readthedocs.org/projects/pyrams/badge/?version=stable)](https://pyrams.readthedocs.io/en/stable/?badge=stable)[![DOI](https://zenodo.org/badge/176599749.svg)](https://zenodo.org/badge/latestdoi/176599749)



Documentation can be [found here](https://pyrams.readthedocs.io/en/stable)

Install from conda-forge:
```
conda install -c conda-forge pyrams
```

or with pip:
```
pip install pyrams
``` 
PyRAMS is distributed under an [MIT License](LICENSE)
